*===============================================================================*
*																				*
*			THIS DO FILE PRODUCES FIGURE 1 IN THE MAIN TEXT						*
* 			AS WELL AS APPENDIX FIGURES A1 AND A2 IN 							*
* 			LONDONO-VELEZ, RODRIGUEZ AND SANCHEZ 								*
*			"UPSTREAM AND DOWNSTREAM IMPACTS OF COLLEGE MERIT-BASED 			*
* 			FINANCIAL AID FOR LOW-INCOME STUDENTS: SER PILO PAGA				*
* 			IN COLOMBIA", AMERICAN ECONOMIC JOURNAL: ECONOMIC POLICY			*
*																				*
*			LAST MODIFIED: 2019-05-29											*
*																				*
*===============================================================================*

	use "${datadir}/data_RD.dta", clear
	
	twoway 	(hist icfes_score_20142 if icfes_per==20142, percent w(5) fc(gray) lcolor(black) lwidth(thin)) ///
			,ytitle(Percentage) xtitle(SABER 11 test score) ///
			graphregion(color(white)) xline(310) text(4.3 400 "SPP eligibility (~ top 9%)")
			graph export Fig1A.pdf, replace
			
	twoway 	(kdensity icfes_score_20142 if icfes_per==20142, lcolor(black) lwidth(medthick)) ///
			(kdensity icfes_score_20142 if eligible_sisben==1 & icfes_per==20142, lcolor(blue) lwidth(medthick) lpattern(longdash)) ///
			,ytitle(Density) xtitle(SABER 11 test score) ///
			graphregion(color(white)) xline(310) text(.009 375 "SPP eligibility") ///
			legend(row(2) order(1 2) lab(1 "All") lab(2 "SISBEN-eligible") position(11) ring(0))
			graph export FigA1.pdf, replace
				
	twoway 	(hist sisben_score if icfes_per==20142, percent w(2) fc(gray) lcolor(black) lwidth(thin)) ///
			,ytitle(Percentage) xtitle(SISBEN wealth index) ///
			graphregion(color(white)) xline(57.21) xline(56.32) xline(40.75) 
			
	replace sisben_score=100 if sisben_score==.	

	twoway 	(hist sisben_score if icfes_per==20142, percent w(5) fc(gray) lcolor(black) lwidth(thin)) ///
			,ytitle(Percentage) xtitle(SISBEN wealth index) ///
			graphregion(color(white)) xline(57.21) xline(56.32) xline(40.75) ///
			xlabel(0 20 40 60 80 100 "NA") text(24 32 "Rural areas", size(small)) ///
			text(27 48.5 "Other urban areas", size(vsmall)) text(32 70 "14 metropolitan areas", size(small))
			graph export Fig1B.pdf, replace		
	
	histogram  running_saber11  if icfes_per==20142 & eligible_sisben==1 &  running_saber11>=-15 & running_saber11<=15, ///
			w(1) discrete freq xtitle(Distance to SABER 11 cutoff) ///
			title(2014) xline(0, lcolor(red) lpattern(dash)) xlabel(-15 -10 -5 0 5 10 15)  ///
			graphregion(color(white)) fcolor(gray)  lc(black) ///
			caption(Sample restricted to SISBEN-eligible individuals., size(small))
			graph export FigA2A2.pdf, replace

	histogram  running_sisben  if icfes_per==20142 & eligible_saber11==1 &  running_sisben>=-5 & running_sisben<=5, ///
			w(0.2) discrete freq xtitle(Distance to SISBEN cutoff) ///
			title(2014) xline(0, lcolor(red) lpattern(dash)) xlabel(-4 -2 0 2 4)  ///
			graphregion(color(white)) fcolor(gray)  lc(black) ///
			caption(Sample restricted to SABER 11-eligible individuals., size(small))			
	graph export FigA2B2.pdf, replace
	
	histogram  running_saber11_placebo  if icfes_per==20132 & eligible_sisben==1 &  running_saber11_placebo>=-3 & running_saber11_placebo<=3, ///
			w(0.1) discrete freq xtitle(Distance to SABER 11 cutoff) ///
			title(2013) xline(0, lcolor(red) lpattern(dash)) xlabel(-3 -2 -1 0 1 2 3)  ///
			graphregion(color(white)) fcolor(gray)  lc(black) ///
			caption(Sample restricted to SISBEN-eligible individuals., size(small))
	graph export FigA2A1.pdf, replace

histogram  running_sisben if icfes_per==20132 & eligible_saber11==1 &  running_sisben>=-5 & running_sisben<=5, ///
			w(0.2) discrete freq xtitle(Distance to SISBEN cutoff) ///
			title(2013) xline(0, lcolor(red) lpattern(dash)) xlabel(-4 -2 0 2 4)  ///
			graphregion(color(white)) fcolor(gray)  lc(black) ///
			caption(Sample restricted to SABER 11-eligible individuals., size(small))			
graph export FigA2B1.pdf, replace
