*===============================================================================*
*																				*
*			THIS DO FILE PRODUCES FIGURE 13 IN THE MAIN TEXT					*
* 			AND APPENDIX FIGURE A8 IN								*
* 			LONDONO-VELEZ, RODRIGUEZ AND SANCHEZ 								*
*			"UPSTREAM AND DOWNSTREAM IMPACTS OF COLLEGE MERIT-BASED 			*
* 			FINANCIAL AID FOR LOW-INCOME STUDENTS: SER PILO PAGA				*
* 			IN COLOMBIA", AMERICAN ECONOMIC JOURNAL: ECONOMIC POLICY			*
*																				*
*			LAST MODIFIED: 2019-05-29											*
*																				*
*===============================================================================*

	use "${datadir}/data_DD.dta", clear

	keep if icfes_per>=20122 
	keep if ss==1
	keep if icfes_age>=14 & icfes_age<=23
	
	keep icfes_per icfes_age icfes_ano icfes_stratum icfes_decil icfes_pct 
	
	* Drop variables without info:
	drop if missing(icfes_stratum) 
	drop if missing(icfes_decil)
	
	*Dymmy deciles Saber 11
	tab icfes_decil, gen(d)
	forvalues p=91/100{
	gen p`p'= icfes_pct==`p'
	}
	gen one=1
	
	collapse (sum) one, by(icfes_per icfes_stratum icfes_pct)
 
	egen totsem=total(one), by(icfes_per)
	egen totsemstrat=total(one), by(icfes_per icfes_stratum)
	egen totsemstrat_d10=total(one) if icfes_pct>=91, by(icfes_per icfes_stratum)
	gen double shstrat_d10=totsemstrat_d10/totsemstrat
	gen base_aux=shstrat_d10 if icfes_per==20122
	gen base_aux2=totsemstrat if icfes_per==20122
	bysort icfes_stratum: egen base20122=max(base_aux)
	bysort icfes_stratum: egen totbase20122=max(base_aux2)
	gen double pctchange=((shstrat_d10/base20122)-1)*100
	gen double pctchange_tot=((totsemstrat/totbase20122)-1)*100
	gen sh=one/totsemstrat
	sort icfes_stratum icfes_pct icfes_per
	gen sh_20122_aux=sh if icfes_per==20122
	by icfes_stratum icfes_pct: egen sh_20122=mean(sh_20122_aux)
	drop sh_20122_aux
	gen delta20122=((sh/sh_20122)-1)*100
	format pctchange* delta20122 %5.0f

	drop base_aux

	gen estrato=.
	replace estrato=icfes_stratum-0.3 if icfes_per==20122
	replace estrato=icfes_stratum-0.15 if icfes_per==20132
	replace estrato=icfes_stratum if icfes_per==20142	
	replace estrato=icfes_stratum+0.15 if icfes_per==20152	
	replace estrato=icfes_stratum+0.3 if icfes_per==20162	

	gen estrato_aux=.
	replace estrato_aux=icfes_stratum-0.2 if icfes_per==20132
	replace estrato_aux=icfes_stratum if icfes_per==20142	
	replace estrato_aux=icfes_stratum+0.2 if icfes_per==20152	
	replace estrato_aux=icfes_stratum+0.4 if icfes_per==20162	
	
twoway  (bar pctchange estrato_aux if icfes_per==20132, barw(0.2) fc(white) lcolor(black) lwidth(thin)) ///
		(bar pctchange estrato_aux if icfes_per==20142, barw(0.2) fc(gs10) lcolor(black) lwidth(thin)) ///
		(bar pctchange estrato_aux if icfes_per==20152, barw(0.2) fc(gs5) lcolor(black) lwidth(thin)) ///
		(bar pctchange estrato_aux if icfes_per==20162, barw(0.2) fc(black) lcolor(black) lwidth(thin)) ///
		,ytitle(Change since 2012 (%)) xtitle(Socioeconomic stratum) graphregion(color(white)) xlab(1(1)6) ///
		legend(row(1) order(1 2 3 4) lab(1 "2013") lab(2 "2014") lab(3 "2015") lab(4 "2016")) 	
		graph export Fig13A.pdf, replace	
		
gen ptile_aux=.
replace ptile_aux=icfes_pct-0.25 if icfes_stratum==1
replace ptile_aux=icfes_pct+0.25 if icfes_stratum==6
twoway  (bar delta20122 ptile_aux if icfes_per==20162 & icfes_stratum==1 & icfes_pct>=90, col(black) barw(0.495)) ///
		(bar delta20122 ptile_aux if icfes_per==20162 & icfes_stratum==6 & icfes_pct>=90, lc(black) fc(white) lwidth(thin) barw(0.495)) ///
		,ytitle(Change in 2012-16 (%)) xtitle(Percentile) graphregion(color(white)) ///
		legend(row(1) order(1 2) lab(1 "Stratum 1") lab(2 "Stratum 6")) xlab(90 91 92 93 94 95 96 97 98 99 100)
		graph export Fig13B.pdf, replace	

twoway  (bar delta20122 estrato_aux if icfes_per==20132 & icfes_pct==100, barw(0.2) fc(white) lcolor(black) lwidth(thin)) ///
		(bar delta20122 estrato_aux if icfes_per==20142 & icfes_pct==100, barw(0.2) fc(gs10) lcolor(black) lwidth(thin)) ///
		(bar delta20122 estrato_aux if icfes_per==20152 & icfes_pct==100, barw(0.2) fc(gs5) lcolor(black) lwidth(thin)) ///
		(bar delta20122 estrato_aux if icfes_per==20162 & icfes_pct==100, barw(0.2) fc(black) lcolor(black) lwidth(thin)) ///
		,ytitle(Change since 2012 (%)) xtitle(Socioeconomic stratum) graphregion(color(white)) xlab(1(1)6) ///
		legend(row(1) order(1 2 3 4) lab(1 "2013") lab(2 "2014") lab(3 "2015") lab(4 "2016")) 	
		graph export FigA8B.pdf, replace	
		

sort icfes_per icfes_stratum
by icfes_per: egen d10=total(totsemstrat_d10)
gen double d10_strata=totsemstrat_d10/d10

		
twoway 	(bar d10_strata estrato if icfes_per==20122, barw(0.149) fc(white) lcolor(black) lwidth(thin)) ///
		(bar d10_strata estrato if icfes_per==20132, barw(0.149) fc(gs13) lcolor(black) lwidth(thin)) ///
		(bar d10_strata estrato if icfes_per==20142, barw(0.149) fc(gs8) lcolor(black) lwidth(thin)) ///
		(bar d10_strata estrato if icfes_per==20152, barw(0.149) fc(gs4) lcolor(black) lwidth(thin)) ///
		(bar d10_strata estrato if icfes_per==20162, barw(0.149) fc(black) lcolor(black) lwidth(thin)) ///
		,ytitle(Percentage) xtitle(Socioeconomic stratum) graphregion(color(white)) xlab(1(1)6) ///
		legend(row(1) order(1 2 3 4 5) lab(1 "2012") lab(2 "2013") lab(3 "2014") lab(4 "2015") lab(5 "2016")) 
		graph export FigA8A.pdf, replace	
