*===============================================================================*
*																				*
*			THIS DO FILE PRODUCES FIGURE 5 IN THE MAIN TEXT	IN					*
* 			LONDONO-VELEZ, RODRIGUEZ AND SANCHEZ 								*
*			"UPSTREAM AND DOWNSTREAM IMPACTS OF COLLEGE MERIT-BASED 			*
* 			FINANCIAL AID FOR LOW-INCOME STUDENTS: SER PILO PAGA				*
* 			IN COLOMBIA", AMERICAN ECONOMIC JOURNAL: ECONOMIC POLICY			*
*																				*
*			LAST MODIFIED: 2019-05-29											*
*																				*
*===============================================================================*
	
 	glo lab_saber11 "xlab(0 0.5 1 1.5 2.0 2.5) ylab(0 0.2 0.4 0.6 0.8 1) xtitle(Normalized SABER 11 test score) caption(Sample restricted to SISBEN-eligible individuals., size(small)) graphregion(color(white)) ytitle("") legend(order(1 2) lab(1 "Fall 2013 test-takers") lab(2 "Fall 2014 test-takers") position(7) ring(0))"
	glo lab_sisben "xline(0, lcolor(red) lpattern(dash)) xlab(-20 -10 0 10 20) ylab(0 0.2 0.4 0.6 0.8 1) xtitle(Distance to SISBEN cutoff) caption(Sample restricted to SABER 11-eligible individuals., size(small)) graphregion(color(white)) ytitle("") legend(order(1 2) lab(1 "Fall 2013 test-takers") lab(2 "Fall 2014 test-takers") position(7) ring(0))"
		
	* Figure 5A:
	use "${datadir}/data_RD.dta", clear
	keep if icfes_per==20132 | icfes_per==20142
	keep icfes_per spadies_any icfes_score_201* beneficiary_spp eligible_sisben 
	
	* Build equivalent cutoff in 2013 from normalized SABER 11 test scores
	replace icfes_score_20142 = round(icfes_score_20142,1)
	
	levelsof icfes_per, local(icfesper)
	foreach per of local icfesper{
	qui: sum icfes_score_`per'
	scalar mean_`per'=r(mean) 
	scalar sd_`per'=r(sd) 
	gen double normal_`per'=(icfes_score_`per'-mean_`per')/sd_`per'
	}
	
	gen double normal = .
	replace normal = normal_20132 if icfes_per==20132
	replace normal = normal_20142 if icfes_per==20142
	
	sum normal if beneficiary_spp==1 & icfes_per==20142
	global min = r(min)
	
	* Test for jump in pre-period (placebo check):
	keep if eligible_sisben==1
	rdrobust spadies_any normal if icfes_per==20132, c($min)
	egen double bin=cut(normal), at(0.04(0.05)2.5)
	
	* Test for statistically significant difference:
	gen post = icfes_per==20142
	gen bin2 = bin*100
	gen did = post*bin2
	reg  spadies_any post##bin2, r
	* Not significant before the cutoff
	
	* Makes plot:
	
	collapse (mean) mean=spadies_any (max) beneficiary_spp, by(icfes_per bin) 
	sum bin if icfes_per==20142 & beneficiary_spp==1
	local xline = r(min)
	twoway 	(scatter mean bin if icfes_per==20132, mc(blue) msymbol(T)) ///
			(scatter mean bin if icfes_per==20142, mc(black)) ///
			, $lab_saber11 xline($min, lcolor(red) lpattern(dash)) 
			graph export Fig5A.pdf, replace	
	
	
	* Makes Figure 5B:
	use "${datadir}/data_RD.dta", clear
	keep if icfes_per==20132 | icfes_per==20142
	keep if eligible_saber11==1
	keep icfes_per spadies_any running_sisben
	
	* Test for jump in pre-period (placebo check):
	rdrobust spadies_any running_sisben if icfes_per==20132
	
	* Test that enrollment only changes above the cutoff:
	egen bin=cut(running_sisben), at(-20(1)20)
	gen post = icfes_per==20142
	gen bin2 = bin+21
	reg spadies_any bin2##post, r
	
	sort icfes_per running_sisben

	* Makes plot:
	collapse (mean) mean=spadies_any, by(icfes_per bin) 
	twoway 	(scatter mean bin if icfes_per==20132, mc(blue) msymbol(T)) ///
			(scatter mean bin if icfes_per==20142, mc(black)) ///
			, $lab_sisben 
			graph export Fig5B.pdf, replace	
				

	
