*===============================================================================*
*																				*
*			THIS DO FILE PRODUCES FIGURES 9, 10, 11, 12 IN THE MAIN TEXT		*
* 			AND APPENDIX FIGURE A4 AND TABLE A6 IN								*
* 			LONDONO-VELEZ, RODRIGUEZ AND SANCHEZ 								*
*			"UPSTREAM AND DOWNSTREAM IMPACTS OF COLLEGE MERIT-BASED 			*
* 			FINANCIAL AID FOR LOW-INCOME STUDENTS: SER PILO PAGA				*
* 			IN COLOMBIA", AMERICAN ECONOMIC JOURNAL: ECONOMIC POLICY			*
*																				*
*			LAST MODIFIED: 2019-05-29											*
*																				*
*===============================================================================*
	
	use "${datadir}/data_DD.dta", clear

	global deciles "d91 d81 d9 d10"
	
	* Drop 2016 test-takers, as our SPADIES data does not include enrollment outcomes for them
	drop if icfes_per==20161 | icfes_per==20162
	
	* Compare test-takers that likely to be high school students i.e., ages 14 to 23
	keep if icfes_age>=14 & icfes_age<=23
	
	* Drop variables without info:
	drop if missing(icfes_stratum) 
	drop if missing(icfes_decil)
	
	*Dymmy deciles Saber 11
	tab icfes_decil, gen(d)

	*Group of deciles
	gen d81=d8+d7+d6+d5+d4+d3+d2+d1
	gen d91=d9+d8+d7+d6+d5+d4+d3+d2+d1
	forvalues p=91/100{
	gen p`p'= icfes_pct==`p'
	}
	
	/* Some HEIs misreport periodically. 
	We want the sub-sample of HEIs that report enrolling at least 1 student to the Ministry of Education each semester (96.5% of HEIs)
	*/
	gsort spadies_hei_id icfes_per - spadies_any
	bysort spadies_hei_id icfes_per: gen aux=_n if spadies_any==1
	gen first =aux==1
	bysort spadies_hei_id: egen nump=total(first) if spadies_any==1
	keep if nump==10 | nump==.

	gen public= spadies_hei_type==1 & spadies_any==1 
	gen private=spadies_hei_type==2 & spadies_any==1 
	
	*Immediate Access By Type of HEI:
	gen ai=spadies_any
	gen aia=spadies_any*spadies_hq
	gen aina=spadies_any*spadies_lq
	gen aiapri=spadies_any*spadies_hq*private
	gen aiapub=spadies_any*spadies_hq*public
	gen ainoacrpri=spadies_any*spadies_lq*private
	gen ainoacrpub=spadies_any*spadies_lq*public
	
	*Enrollment by strata, saber 11 decile (plus interacted), and percentile
	foreach o in  ai aia aina aiapri aiapub ainoacrpri ainoacrpub{
	foreach e of numlist 123 456{
	gen `o'`e'=`o'*icfes_stratum`e'
	replace `o'`e'=. if icfes_stratum`e'==0
	foreach v in ${deciles} {
	gen `o'`e'`v'=`o'*icfes_stratum`e'*`v'
	replace `o'`e'`v'=. if icfes_stratum`e'==0 | `v'==0
	}
	}
	foreach d in ${deciles}{
	gen `o'`d'=`o'*`d'
	replace `o'`d'=. if `d'==0
	}
	gen p`o'=`o'*icfes_pct
	replace p`o'=. if p`o'==0
	}
	
		
	gen post = icfes_per>20132
	gen did = ss*post
	
	******************************************
	************* DID TABLE A.6 **************
	******************************************	
	
	preserve
	matrix results = J(24,7,.)
	local oo = 0
	foreach o in ai aia aiapri aiapub aina ainoacrpri ainoacrpub {
	local ee = 0
	foreach e of numlist 123 456 {
	qui: areg `o'`e' post ss did, abs(icfes_municipality) vce(robust)
	matrix results[1+`ee',1+`oo']=round(_b[did],0.0001)
	matrix results[2+`ee',1+`oo']=round(_se[did],0.0001)
	matrix results[3+`ee',1+`oo']=round(_b[_cons],0.0001)
	local dd = 0
	foreach d in d91 d10 {
	qui: areg `o'`e'`d' post ss did, abs(icfes_municipality) vce(robust)
	matrix results[4+`ee'+`dd',1+`oo']=round(_b[did],0.0001)
	matrix results[5+`ee'+`dd',1+`oo']=round(_se[did],0.0001)
	matrix results[6+`ee'+`dd',1+`oo']=round(_b[_cons],0.0001)
	local dd = `dd'+3
	}
	local ee = `ee'+9
	}
	qui: areg d10 post ss did if `o'==1, abs(spadies_hei_id) vce(cluster spadies_hei_id)
	matrix results[19,1+`oo']=round(_b[did],0.0001)
	matrix results[20,1+`oo']=round(_se[did],0.0001)
	matrix results[21,1+`oo']=round(_b[_cons],0.0001)
	qui: areg icfes_stratum123 post ss did if `o'==1, abs(spadies_hei_id) vce(cluster spadies_hei_id)
	matrix results[22,1+`oo']=round(_b[did],0.0001)
	matrix results[23,1+`oo']=round(_se[did],0.0001)
	matrix results[24,1+`oo']=round(_b[_cons],0.0001)
	local oo = `oo'+1
	}
	matrix list results
	svmat results
	keep results*
	drop if _n>24
	rename results1 any
	rename results2 hq
	rename results3 hq_pri
	rename results4 hq_pub
	rename results5 lq
	rename results6 lq_pri
	rename results7 lq_pub
	* Table A.6:
	export excel using tables, sheet("did") sheetmod firstrow(variables)
	restore 
	
	******************************************
	*************ENROLLMENT******************
	******************************************
	cap drop coeff* upper* lower* x
	
	** Enrollment in higher education by type and strata:

	foreach v in ai aia aina aiapri aiapub ainoacrpri ainoacrpub {
	areg `v' ib(2013).icfes_ano##ss, abs(icfes_municipality) vce(robust)
	matrix list e(b)
	mat c_`v' = [ _b[2011.icfes_ano#1.ss]\ _b[2012.icfes_ano#1.ss]\0\ _b[2014.icfes_ano#1.ss]\ _b[2015.icfes_ano#1.ss]]
	mat se_`v' = [_se[2011.icfes_ano#1.ss]\_se[2012.icfes_ano#1.ss]\0\ _se[2014.icfes_ano#1.ss]\ _se[2015.icfes_ano#1.ss]]
	mat upper_`v' = c_`v'+((1.96)*se_`v')
	mat lower_`v' = c_`v'-((1.96)*se_`v')
	mat data_`v' = [c_`v', upper_`v', lower_`v']
	svmat data_`v'
	rename data_`v'1 coeff_`v'
	rename data_`v'2 upper_`v' 
	rename data_`v'3 lower_`v'
	foreach e of numlist 123 456 {
	areg `v'`e' ib(2013).icfes_ano##ss, abs(icfes_municipality) vce(robust)
	matrix list e(b)
	mat c_`v'`e' = [ _b[2011.icfes_ano#1.ss]\ _b[2012.icfes_ano#1.ss]\0\ _b[2014.icfes_ano#1.ss]\ _b[2015.icfes_ano#1.ss]]
	mat se_`v'`e' = [ _se[2011.icfes_ano#1.ss]\_se[2012.icfes_ano#1.ss]\0\ _se[2014.icfes_ano#1.ss]\ _se[2015.icfes_ano#1.ss]]
	mat upper_`v'`e' = c_`v'`e'+((1.96)*se_`v'`e')
	mat lower_`v'`e' = c_`v'`e'-((1.96)*se_`v'`e')
	mat data_`v'`e' = [c_`v'`e', upper_`v'`e', lower_`v'`e']
	svmat data_`v'`e'
	rename data_`v'`e'1 coeff_`v'`e'
	rename data_`v'`e'2 upper_`v'`e'
	rename data_`v'`e'3 lower_`v'`e'
	foreach d in ${deciles} {
	areg `v'`e'`d' ib(2013).icfes_ano##ss, abs(icfes_municipality) vce(robust)
	matrix list e(b)
	mat c_`v'`e'`d' = [_b[2011.icfes_ano#1.ss]\ _b[2012.icfes_ano#1.ss]\0\ _b[2014.icfes_ano#1.ss]\ _b[2015.icfes_ano#1.ss]]
	mat se_`v'`e'`d' = [ _se[2011.icfes_ano#1.ss]\_se[2012.icfes_ano#1.ss]\0\ _se[2014.icfes_ano#1.ss]\ _se[2015.icfes_ano#1.ss]]
	mat upper_`v'`e'`d' = c_`v'`e'`d'+((1.96)*se_`v'`e'`d')
	mat lower_`v'`e'`d' = c_`v'`e'`d'-((1.96)*se_`v'`e'`d')
	mat data_`v'`e'`d' = [c_`v'`e'`d', upper_`v'`e'`d', lower_`v'`e'`d']
	svmat data_`v'`e'`d'
	rename data_`v'`e'`d'1 coeff_`v'`e'`d'
	rename data_`v'`e'`d'2 upper_`v'`e'`d'
	rename data_`v'`e'`d'3 lower_`v'`e'`d'
	}
	}
	}
	
	
	************************************************
	*******COMPOSITION OF STUDENTS INSIDE IES*******
	************************************************
	
	* Percentile of Saber 11 student composition in colleges (conditional on immediate enrollment)
	foreach v in ai aia aina aiapri aiapub ainoacrpri ainoacrpub {
	areg p`v' ib(2013).icfes_ano##ss if `v'==1, abs(spadies_hei_id) vce(cluster spadies_hei_id)
	matrix list e(b)
	mat c_p`v' = [_b[2011.icfes_ano#1.ss]\ _b[2012.icfes_ano#1.ss]\0\ _b[2014.icfes_ano#1.ss]\ _b[2015.icfes_ano#1.ss]]
	mat se_p`v' = [_se[2011.icfes_ano#1.ss]\_se[2012.icfes_ano#1.ss]\0\ _se[2014.icfes_ano#1.ss]\ _se[2015.icfes_ano#1.ss]]
	mat upper_p`v' = c_p`v'+((1.96)*se_p`v')
	mat lower_p`v' = c_p`v'-((1.96)*se_p`v')
	mat data_p`v' = [c_p`v', upper_p`v', lower_p`v']
	svmat data_p`v'
	rename data_p`v'1 coeff_p`v'
	rename data_p`v'2 upper_p`v'
	rename data_p`v'3 lower_p`v'
	foreach d of numlist 10{
	areg d`d' ib(2013).icfes_ano##ss if `v'==1, abs(spadies_hei_id) vce(cluster spadies_hei_id)
	matrix list e(b)
	mat c_d`d'`v' = [_b[2011.icfes_ano#1.ss]\ _b[2012.icfes_ano#1.ss]\0\ _b[2014.icfes_ano#1.ss]\ _b[2015.icfes_ano#1.ss]]
	mat se_d`d'`v' = [_se[2011.icfes_ano#1.ss]\_se[2012.icfes_ano#1.ss]\0\ _se[2014.icfes_ano#1.ss]\ _se[2015.icfes_ano#1.ss]]
	mat upper_d`d'`v' = c_d`d'`v'+((1.96)*se_d`d'`v')
	mat lower_d`d'`v' = c_d`d'`v'-((1.96)*se_d`d'`v')
	mat data_d`d'`v' = [c_d`d'`v', upper_d`d'`v', lower_d`d'`v']
	svmat data_d`d'`v'
	rename data_d`d'`v'1 coeff_d`d'`v'
	rename data_d`d'`v'2 upper_d`d'`v'
	rename data_d`d'`v'3 lower_d`d'`v'
	}
	foreach e of numlist 123 456{
	areg icfes_stratum`e' ib(2013).icfes_ano##ss if `v'==1, abs(spadies_hei_id) vce(cluster spadies_hei_id)
	matrix list e(b)
	mat c_sh`v'`e' = [_b[2011.icfes_ano#1.ss]\ _b[2012.icfes_ano#1.ss]\0\ _b[2014.icfes_ano#1.ss]\ _b[2015.icfes_ano#1.ss]]
	mat se_sh`v'`e' = [_se[2011.icfes_ano#1.ss]\_se[2012.icfes_ano#1.ss]\0\ _se[2014.icfes_ano#1.ss]\ _se[2015.icfes_ano#1.ss]]
	mat upper_sh`v'`e' = c_sh`v'`e'+((1.96)*se_sh`v'`e')
	mat lower_sh`v'`e' = c_sh`v'`e'-((1.96)*se_sh`v'`e')
	mat data_sh`v'`e' = [c_sh`v'`e', upper_sh`v'`e', lower_sh`v'`e']
	svmat data_sh`v'`e'
	rename data_sh`v'`e'1 coeff_sh`v'`e'
	rename data_sh`v'`e'2 upper_sh`v'`e'
	rename data_sh`v'`e'3 lower_sh`v'`e'
	}
	}
	
	gen x = 2011+_n-1
	keep if x<=2015
	keep coeff* upper* lower* x
	
**********************************************
**********ENROLLMENT GRAPHS*******************
**********************************************
glo labfig "xtitle(Year) ytitle(Coefficient) graphregion(color(white)) xlabel(2011 2012 2013 2014 2015) xline(2013.5, lc(red) lpattern(dash)) yline(0, lc(gray) lpattern(dash) lwidth(thin))"
	
* Figure 9:

	cap drop xm xp
	gen xm = x-0.05	
	gen xp = x+0.05	
	twoway 	(conn coeff_ai123d81 xm, color(gray)m(O)msiz(medsmall)) ///
			(rcap upper_ai123d81 lower_ai123d81 xm, color(gray)m(O)msiz(medsmall)) ///
			(conn coeff_ai123d9 x, color(black)m(T)msiz(medsmall)) ///
			(rcap upper_ai123d9 lower_ai123d9 x, color(black)m(T)msiz(medsmall)) ///
			(conn coeff_ai123d10 xp, color(blue)m(D)msiz(medsmall)) ///
			(rcap upper_ai123d10 lower_ai123d10 xp, color(blue)m(D)msiz(medsmall)) ///
			, legend(row(1) order(1 3 5) lab(1 "Deciles 1-8") lab(3 "Decile 9") ///
			lab(5 "Decile 10")) $labfig ysc(r(-0.05 0.2)) ylab(-0.05(.05)0.2)
			graph export Fig9A.pdf, replace
	
	twoway 	(conn coeff_ai456d81 xm, color(gray)m(O)msiz(medsmall)) ///
			(rcap upper_ai456d81 lower_ai456d81 xm, color(gray)m(O)msiz(medsmall)) ///
			(conn coeff_ai456d9 x, color(black)m(T)msiz(medsmall)) ///
			(rcap upper_ai456d9 lower_ai456d9 x, color(black)m(T)msiz(medsmall)) ///
			(conn coeff_ai456d10 xp, color(blue)m(D)msiz(medsmall)) ///
			(rcap upper_ai456d10 lower_ai456d10 xp, color(blue)m(D)msiz(medsmall)) ///
			, legend(row(1) order(1 3 5) lab(1 "Deciles 1-8") lab(3 "Decile 9") ///
			lab(5 "Decile 10")) $labfig ysc(r(-0.05 0.2)) ylab(-0.05(.05)0.2)
			graph export Fig9B.pdf, replace
			
			
* Figure 10:

	cap drop xm xp
	gen xmm = x-0.03
	gen xm = x-0.01
	gen xp = x+0.01
	gen xpp = x+0.03
	
	twoway 	(conn coeff_ainoacrpri123d91 xmm, color(gray)m(O)msiz(medsmall)) ///
			(rcap upper_ainoacrpri123d91 lower_ainoacrpri123d91 xmm, color(gray)m(O)msiz(medsmall)) ///
			(conn coeff_ainoacrpub123d91 xm, color(black)m(T)msiz(medsmall)) ///
			(rcap upper_ainoacrpub123d91 lower_ainoacrpub123d91 xm, color(black)m(T)msiz(medsmall)) ///
			(conn coeff_ainoacrpri123d10 xp, color(green)m(D)msiz(medsmall)) ///
			(rcap upper_ainoacrpri123d10 lower_ainoacrpri123d10 xp, color(green)m(D)msiz(medsmall)) ///
			(conn coeff_ainoacrpub123d10 xpp, color(blue)m(S)msiz(medsmall)) ///
			(rcap upper_ainoacrpub123d10 lower_ainoacrpub123d10 xpp, color(blue)m(S)msiz(medsmall)) ///
			, legend(row(2) order(1 3 5 7) lab(1 "Deciles 1-9: Private") lab(3 "Deciles 1-9: Public") ///
			lab(5 "Decile 10: Private") lab(7 "Decile 10: Public")) $labfig ysc(r(-0.05 0.05)) ylab(-0.05(.05)0.05)
			graph export Fig10A.pdf, replace
			
	twoway 	(conn coeff_aiapri123d91 xmm, color(gray)m(O)msiz(medsmall)) ///
			(rcap upper_aiapri123d91 lower_aiapri123d91 xmm, color(gray)m(O)msiz(medsmall)) ///
			(conn coeff_aiapub123d91 xm, color(black)m(T)msiz(medsmall)) ///
			(rcap upper_aiapub123d91 lower_aiapub123d91 xm, color(black)m(T)msiz(medsmall)) ///
			(conn coeff_aiapri123d10 xp, color(green)m(D)msiz(medsmall)) ///
			(rcap upper_aiapri123d10 lower_aiapri123d10 xp, color(green)m(D)msiz(medsmall)) ///
			(conn coeff_aiapub123d10 xpp, color(blue)m(S)msiz(medsmall)) ///
			(rcap upper_aiapub123d10 lower_aiapub123d10 xpp, color(blue)m(S)msiz(medsmall)) ///
			, legend(row(2) order(1 3 5 7) lab(1 "Deciles 1-9: Private") lab(3 "Deciles 1-9: Public") ///
			lab(5 "Decile 10: Private") lab(7 "Decile 10: Public")) $labfig ysc(r(-0.05 0.15)) ylab(-0.05(.05)0.2)
			graph export Fig10B.pdf, replace
	
	
	* Figure A4:
	twoway 	(conn coeff_ainoacrpri456d91 xmm, color(gray)m(O)msiz(medsmall)) ///
			(rcap upper_ainoacrpri456d91 lower_ainoacrpri456d91 xmm, color(gray)m(O)msiz(medsmall)) ///
			(conn coeff_ainoacrpub456d91 xm, color(black)m(T)msiz(medsmall)) ///
			(rcap upper_ainoacrpub456d91 lower_ainoacrpub456d91 xm, color(black)m(T)msiz(medsmall)) ///
			(conn coeff_ainoacrpri456d10 xp, color(green)m(D)msiz(medsmall)) ///
			(rcap upper_ainoacrpri456d10 lower_ainoacrpri456d10 xp, color(green)m(D)msiz(medsmall)) ///
			(conn coeff_ainoacrpub456d10 xpp, color(blue)m(S)msiz(medsmall)) ///
			(rcap upper_ainoacrpub456d10 lower_ainoacrpub456d10 xpp, color(blue)m(S)msiz(medsmall)) ///
			, legend(row(2) order(1 3 5 7) lab(1 "Deciles 1-9: Private") lab(3 "Deciles 1-9: Public") ///
			lab(5 "Decile 10: Private") lab(7 "Decile 10: Public")) $labfig ysc(r(-0.05 0.05)) ylab(-0.05(.05)0.05)
			graph export FigA4A.pdf, replace
			
	twoway 	(conn coeff_aiapri456d91 xmm, color(gray)m(O)msiz(medsmall)) ///
			(rcap upper_aiapri456d91 lower_aiapri456d91 xmm, color(gray)m(O)msiz(medsmall)) ///
			(conn coeff_aiapub456d91 xm, color(black)m(T)msiz(medsmall)) ///
			(rcap upper_aiapub456d91 lower_aiapub456d91 xm, color(black)m(T)msiz(medsmall)) ///
			(conn coeff_aiapri456d10 xp, color(green)m(D)msiz(medsmall)) ///
			(rcap upper_aiapri456d10 lower_aiapri456d10 xp, color(green)m(D)msiz(medsmall)) ///
			(conn coeff_aiapub456d10 xpp, color(blue)m(S)msiz(medsmall)) ///
			(rcap upper_aiapub456d10 lower_aiapub456d10 xpp, color(blue)m(S)msiz(medsmall)) ///
			, legend(row(2) order(1 3 5 7) lab(1 "Deciles 1-9: Private") lab(3 "Deciles 1-9: Public") ///
			lab(5 "Decile 10: Private") lab(7 "Decile 10: Public")) $labfig ysc(r(-0.05 0.05)) ylab(-0.05(.05)0.05)
			graph export FigA4B.pdf, replace


************************************************************
**********IES STUDENT COMPOSITION  GRAPHS*******************
************************************************************

*Class Diversity
	
	
	cap drop xm xp
	gen xm = x-0.02	
	gen xp = x+0.02
	twoway 	(conn coeff_shaiapri123 xm, color(black)m(O)msiz(medsmall)) ///
			(rcap upper_shaiapri123 lower_shaiapri123 xm, color(black)m(O)msiz(medsmall)) ///
			(conn coeff_shaiapub123 xp, color(blue)m(T)msiz(medsmall)) ///
			(rcap upper_shaiapub123 lower_shaiapub123 xp, color(blue)m(T)msiz(medsmall)) ///
			, legend(row(1) order(1 3) lab(1 "Private") lab(3 "Public")) $labfig ysc(r(-0.05 0.15)) ylab(-0.05(.05)0.15)
			graph export Fig12B.pdf, replace
			
	twoway 	(conn coeff_shainoacrpri123 xm, color(black)m(O)msiz(medsmall)) ///
			(rcap upper_shainoacrpri123 lower_shainoacrpri123 xm, color(black)m(O)msiz(medsmall)) ///
			(conn coeff_shainoacrpub123 xp, color(blue)m(T)msiz(medsmall)) ///
			(rcap upper_shainoacrpub123 lower_shainoacrpub123 xp, color(blue)m(T)msiz(medsmall)) ///
			, legend(row(1) order(1 3) lab(1 "Private") lab(3 "Public")) $labfig ysc(r(-0.05 0.15)) ylab(-0.05(.05)0.15)
			graph export Fig12A.pdf, replace
			

*Percentile	
			
	cap drop xm xp
	gen xm = x-0.02	
	gen xp = x+0.02
	
	twoway 	(conn coeff_d10ainoacrpri xm, color(black)m(O)msiz(medsmall)) ///
			(rcap upper_d10ainoacrpri lower_d10ainoacrpri xm, color(black)m(O)msiz(medsmall)) ///
			(conn coeff_d10ainoacrpub xp, color(blue)m(T)msiz(medsmall)) ///
			(rcap upper_d10ainoacrpub lower_d10ainoacrpub xp, color(blue)m(T)msiz(medsmall)) ///
			, legend(row(1) order(1 3) lab(1 "Private") lab(3 "Public")) $labfig ysc(r(-0.1 0.15)) ylab(-0.1(.05)0.15)
			graph export Fig11A.pdf, replace
	
	twoway 	(conn coeff_d10aiapri xm, color(black)m(O)msiz(medsmall)) ///
			(rcap upper_d10aiapri lower_d10aiapri xm, color(black)m(O)msiz(medsmall)) ///
			(conn coeff_d10aiapub xp, color(blue)m(T)msiz(medsmall)) ///
			(rcap upper_d10aiapub lower_d10aiapub xp, color(blue)m(T)msiz(medsmall)) ///
			, legend(row(1) order(1 3) lab(1 "Private") lab(3 "Public")) $labfig ysc(r(-0.1 0.15)) ylab(-0.1(.05)0.15)
			graph export Fig11B.pdf, replace
	

			

			
